use std::path::PathBuf;
use std::io::BufReader;
use std::thread;
use std::time::Duration;
use std::fs::File;

#[derive(Clone, Default)]
pub struct Sound {
    pub location: PathBuf,
    data: Vec<u8>,
    pub roll: i32,
    pub rate: i32
}

impl Sound {
    pub fn new(location: &str) -> Sound {
        Sound {
            location: PathBuf::from(location),
            data: vec![],
            roll: 0,
            rate: 8
        }
    }
    pub fn play(&self, device: &rodio::Device) {
        if let Ok(file) = std::fs::File::open(&self.location) {
            // let dec = rodio::Decoder::new(BufReader::new(file)).unwrap();
            let reader = BufReader::new(file);
            let d = device.clone();
            let _sink = rodio::play_once(d, reader).unwrap().detach();

        }
    }
}

pub struct Bar {
    pub repeat: i32,
    pub length: i32,
    pub bpm: i32,
    pub sounds: Vec<Sound>
}

impl Default for Bar {
    fn default() -> Bar {
        Bar {
            repeat: 0,
            length: 4,
            bpm: 120,
            sounds: vec![]
        }
    }
}

impl Bar {
    pub fn play(&self, device: &rodio::Device) {
        let delay = ((60.0 / self.bpm as f32)*1000.0) as u64;
        dbg!(&delay);
        for _ in 0..self.repeat+1 {

            for sound in &self.sounds {
                sound.play(device);
                thread::sleep(Duration::from_millis(delay));

            }
        }
    }
}